\name{dclust}
\alias{dclust}
\title{ Decluster data by runs declustering. }
\description{
Decluster data by assuming that exceedances belong to the same cluster if
they are separated by fewer than 'r' (run length) values below a given
threshold.
}
\usage{
dclust(xdat, u, r, cluster.by = NULL)
}
\arguments{
  \item{xdat}{ a single numeric vector of data to be declustered.}
  \item{u}{ single number or vector of thresholds. }
  \item{r}{ run length }
  \item{cluster.by}{ If there are blocks implying a natural clustering that is to be preserved
	(e.g., if data cover several years, but only for a single season), this is a vector
	defining the blocks to ensure that clusters do not cross over from one block to another.}
}
\details{
This function applies runs declustering to automatically decluster a dataset.
To ensure that clusters do not cross natural or decided boundaries, use
the 'cluster.by' option.  That is, suppose data are measured only in the summer,
say from June 1 through August 1.  In such a case, it is perhaps not desired to have
a value from August 1, 2003 and June 1, 2004 in the same cluster.  To account for this,
create a 'cluster.by' vector defining years in order to keep clusters within years.
For the example of data from June 1 to August 1 (62 days), a vector like
c(rep(1, 62), rep(2, 62), ..., rep(n, 62)) should be used for the 'cluster.by' argument.

This function will return a vector of the same length as the original data
vector, but with maximums from each cluster followed by 'filler' numbers that
are below the given threshold, 'u'.

Missing values are not handled.  The function will still run, but the results
will be questionable.
}
\value{ A list with components:
  \item{xdat.dc}{Maximums from each cluster with additional filler values below
	the given threshold 'u' in order to maintain the same length as the
	original data vector 'xdat'.  This is for compatability with extRemes
	GUI data object of class ``ev.data".}
  \item{ncluster}{The number of clusters found by runs declustering.}
  \item{clust}{numeric vector giving the clusters.}
}
\references{ Coles, Stuart (2001).  An Introduction to Statistical Modeling of
	Extreme Values.  Springer-Verlag, London. }
\author{ Eric Gilleland }

\examples{
# Load a dataset.
data(Tphap)

plot( Tphap[,"MaxT"])
abline( h=115)

# Decluster using a threshold of 115 degrees and a run length of 'r=1'.
temp <- dclust(xdat=Tphap[,"MaxT"], u=115, r=1, cluster.by = Tphap[,"Year"])
temp[["ncluster"]] # See how many clusters were found.

# Now do the same as above, but with a run length of 3 for comparison.
# Note: 'r=2' gives same clusters as 'r=1' for these data.
temp2 <- dclust(xdat=Tphap[,"MaxT"], u=115, r=3, cluster.by = Tphap[,"Year"])
temp2[["ncluster"]]

}
\keyword{ manip}

\eof
\name{extRemes internal }
\alias{bisearch}
\alias{extremalind.gui}
\alias{gev.ret}
\alias{gev.rlci}
\alias{gpd.ret}
\alias{gpd.rlci}
\alias{indicatorTransform.gui}
\alias{llhrt.gui}
\alias{plot.gev.fit}
\alias{plot.gpd.fit}
\alias{plot.gum.fit}
\alias{plot.pp.fit}
\alias{plot.rlarg.fit}
\alias{rl.gev.fit}
\alias{rl.gpd.fit}
\alias{scatterplot.gui}
\alias{damage}  
\alias{Denmint}
\alias{Denver}
\alias{Flood}
\alias{ftcanmax}
\alias{FtCoPrec}
\alias{HEAT}
\alias{Peak}
\alias{PORTw}
\alias{Potomac}
\alias{Rsum}
\alias{SEPTsp}
\alias{Tphap}
\alias{YDarwin}
\alias{affine.gui}
\alias{ppfit.gui}
\alias{gevdiag.gui}
\alias{ppfitrange.gui}
\alias{gevf.gui}
\alias{gpdsim.gui}
\alias{gevparamCI.gui}
\alias{hist.gev.fit}
\alias{hist.gpd.fit}
\alias{histogram.gui}
\alias{hist.pp.fit}
\alias{rlargf.gui}
\alias{decluster.gui}
\alias{deviancestat}
\alias{rlplot.gui}
\alias{summary.gev.fit}
\alias{summary.gpd.fit}
\alias{load.data}
\alias{summary.pp.fit}
\alias{diagnostic.plots}
\alias{gevsim.gui}
\alias{logdr.gui}
\alias{summary.rlarg.fit}
\alias{gevsim.gui}
\alias{logtrans.gui}
\alias{trigtrans.gui}
\alias{gpddiag.gui}
\alias{mrlplot.gui}
\alias{view.data}
\alias{gpdf.gui}
\alias{negtrans.gui}
\alias{zzz}
\alias{fitdiag.gui}
\alias{gpdfitrange.gui}
\alias{fitsummary.gui}
\alias{gpdparamCI.gui}
\alias{plotTS.gui}
\alias{poisson.gui}
\alias{scrubber.gui}

\title{
  extRemes internal and secondary functions
}

\description{
Listed below are supporting fucntions for the major methods in extRemes.
Most of the functions control GUI interfaces for the R package ismev.
}

\usage{
bisearch(x1, x2, f, tol = 1e-07, niter = 25, upcross.level = 0)
extremalind.gui( base.txt)
gev.ret(A, b, c, p = 100, ...)
gev.rlci(z, m, prange = NULL, conf = 0.95, nint = 100)
gpd.ret(z, p)
gpd.rlci(z, m, prange=NULL, npy = 365, conf = 0.95, nint = 100)
indicatorTransform.gui(base.txt)
llhrt.gui(base.txt)
plot.gev.fit(x, ...)
plot.gpd.fit(x, ...)
plot.gum.fit(x, ...)
plot.pp.fit(x, ...)
plot.rlarg.fit(x, ...)
rl.gev.fit(a, mat, dat)
rl.gpd.fit(a, u, la, n, npy, mat, dat, xdat)
scatterplot.gui(base.txt)
damage
Denmint
Denver
Flood
ftcanmax
FtCoPrec
HEAT
Peak
PORTw
Potomac
Rsum
SEPTsp
Tphap
YDarwin
affine.gui(base.txt)
ppfit.gui(base.txt)
gevdiag.gui(base.txt)
ppfitrange.gui(base.txt) 
gevf.gui(base.txt) 
gpdsim.gui(base.txt) 
gevparamCI.gui(base.txt) 
hist.gev.fit(x, breaks.method="Sturges", ...)
hist.gpd.fit(x, breaks.method="Sturges", ...)
hist.pp.fit(x, breaks.method="Sturges", ...)
rlargf.gui(base.txt)
rlplot.gui(base.txt)
decluster.gui(base.txt)
deviancestat(l1, l2, v, alpha=0.05)
histogram.gui(base.txt) 
summary.gev.fit(object, ...)
summary.gpd.fit(object, ...)
load.data(base.txt)
summary.pp.fit(object, ...)
diagnostic.plots 
gevsim.gui(base.txt) 
logdr.gui(base.txt) 
summary.rlarg.fit(object, ...)
logtrans.gui(base.txt)
trigtrans.gui(base.txt)
gpddiag.gui(base.txt)
mrlplot.gui(base.txt)
view.data(base.txt)
gpdf.gui(base.txt)
negtrans.gui(base.txt)
zzz 
fitdiag.gui(base.txt)
gpdfitrange.gui(base.txt)
fitsummary.gui(base.txt)
gpdparamCI.gui(base.txt)
plotTS.gui(base.txt)
poisson.gui(base.txt)
scrubber.gui(base.txt)
}
\keyword{internal}
\keyword{misc}

\eof
\name{extRemes}
\alias{extRemes}
\title{extRemes -- The Extremes Toolkit: Weather and Climate Applications of Extreme Value Statistics}
\description{
'extRemes' is a graphical user interface (GUI) for modeling extreme values.  This package relies on the
'ismev' package, and most of the underlying functions are from this package.  'ismev' is an R port of
Stuart Coles' S-Plus extreme value statistical routines.

For help, see the tutorial at:

http://www.esig.ucar.edu/extremevalues/evtk.shtml
}
\keyword{misc}

\eof
\name{extremalindex}
\alias{extremalindex}
\title{ Estimate the extremal index (theta) }
\description{
Estimates the extremal index based on the intervals estimator due to
Ferro and Segers (2003).
}
\usage{
extremalindex(xdat, u)
}
\arguments{
  \item{xdat}{ n X 1 numeric vector of the data. }
  \item{u}{ User defined threshold.  May be a single number or a numeric n X 1
	vector.}
}
\details{
The extremal index is a useful indicator of how much clustering of exceedances
of a threshold occurs in the limit of the distribution.  If theta = 1, then the
data is independent and if theta < 1, then there is some dependency (clustering)
in the limit.

There are many possible estimators of the extremal index.  The one used here is
the intervals estimator described in Ferro and Segers (2003).  It is unbiased
in the mean and can be used to estimate the number of clusters, which is also
done by this function.
}
\value{ A list with components:
  \item{theta }{The intervals estimate of the extremal index (theta).}
  \item{msg }{A message stating whether any interexceedance times were above 2
	and possibly other pertinent information.}
  \item{C}{The estimated number of clusters (handles ties).}
  \item{run.length}{The estimated run length for runs declustering.}
}
\references{ Ferro, C.A.T. and Segers, J. (2003): Inference for clusters of
	extreme values, J.R. Statist. Soc. B, 65 (2): 545-556. }
\author{ Eric Gilleland }
\seealso{ \code{dclust}}
\examples{
data( Tphap)
temp <- -Tphap[,"MinT"]
look <- extremalindex( temp, -70)
look
}
\keyword{univar}

\eof
\name{extremes.gui}
\alias{extremes.gui}
\title{ open the toolkit main dialog window }
\description{
Simply opens the toolkit dialog window.
}
\usage{
extremes.gui()
}
\value{
Opens a Tcl/Tk dialog window.
}
\author{ Greg Young and Eric Gilleland }
\note{ This function is called on start-up (i.e., when library( extRemes) is invoked).
This function may be used to re-open the main dialog window if it is closed while the
package is still loaded. }

\examples{
## Don't run
# extremes()
}
\keyword{ misc }% at least one, from doc/KEYWORDS

\eof
\name{gen.gev}
\alias{gen.gev}
\alias{gen.gpd}
\title{ Simulate data from a generalized extreme value (GEV)}
\description{
Generates data from a GEV (GPD) using 'runif' (and 'rexp') function.  May also
incorporate a linear trend in location parameter of GEV.
}
\usage{
gen.gev(p, n, trend = NULL)
gen.gpd(n,sigma,xi,u)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{p}{ A $1\times 3$ vector indicating the mean, scale and shape of the
		GEV, respectively. }
  \item{n}{ The sample size to generate.}
  \item{trend}{ Slope of the location parameter trend (if desired). }
  \item{sigma}{ Scale parameter of GPD.}
  \item{xi}{ Shape parameter of GPD.}
  \item{u}{ Threshold for GPD.}
}
\details{
Value returned (with no trend) is derived from the follwing formula (GEV).
$\mu + \sigma \frac{X^{-\xi - 1}}{\xi}$, where $X$ is a uniform random
variable.

For GPD the formula is:
$\frac{\sigma}{\xi}\cdot((1-$runif$(n))^{-\xi-1}$ for $\xi\neq 0$ and
rexp$(n,$ rate=$\frac{1}{\sigma}$ for $\xi = 0$.

}
\value{
Returns a vector of simulated data.
}
\references{ Coles, Stuart.  "An introduction to statistical modeling of
     extreme values", Springer-Verlag (London), 2001. }
\author{ Functions written by Eric Gilleland and Greg Young.}

\seealso{ From \code{ismev} package: \code{gev.fit}, \code{gev.diag},
		\code{gpd.fit}, \code{gpd.diag}}

\examples{
# obtain a GEV with mean, 4, scale 1.5 and shape of -0.1
mu <- 4 # location parameter
sigma <- 1.5 # scale parameter
xi <- -0.1 # shape parameter

params <- c( mu, sigma, xi)

# generate a sample of size 25
gen1 <- gen.gev( p=params, n=25)

# Now generate one with a trend.
gen2 <- gen.gev( p=params, n=25, trend=0.1)

# Fit 'gen1' to a GEV distribution and plot the diagnostics.
gen1.fit <- gev.fit( gen1)
class( gen1.fit) <- "gev.fit"
plot( gen1.fit)

# Fit 'gen2' to a GEV distribution and plot the diagnostics.
gen2.fit1 <- gev.fit( gen2)
class( gen2.fit1) <- "gev.fit"
plot( gen2.fit1)

}
\keyword{ distribution }

\eof
\name{gev.parameterCI}
\alias{gev.parameterCI}
\alias{gpd.parameterCI}
\title{ Return level and shape parameter confidence intervals for GEV (or GP) distribution. }
\description{
Computes confidence intervals for return levels and/or shape parameters of GEV (or GP) using
the profile likelihood appraoch.
}
\usage{
gev.parameterCI(z, m, rl.xlow, rl.xup, xi.xlow=NULL, xi.xup=NULL, conf = 0.95,
			nint = 100, rl.only=FALSE, xi.only=FALSE, make.plot=FALSE)

gpd.parameterCI(z, m, conf = 0.95, nint = 100, rl.xup=NULL, rl.xlow=NULL,
			xi.xup=NULL, xi.xlow=NULL, rl.only=FALSE,
			xi.only=FALSE, make.plot=FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{z}{ object from \code{gev.fit} or \code{gpd.fit} functions of the \code{ismev} package.}
  \item{m}{ m-year return level for which to calculate confidence interval. }
  \item{rl.xlow}{ initial guess of lower limit for return level (generally should be lower than actual limit).
			If NULL, this function will make its own guess--it is recommended to plot the profile
			likelihood when finding these limits automatically (\code{make.plot}=TRUE).}
  \item{rl.xup}{ initial guess of upper limit for return level (generally should be higher than actual limit).
			If NULL, this function will make its own guess--it is recommended to plot the profile
                        likelihood when finding these limits automatically (\code{make.plot}=TRUE).}
  \item{xi.xlow}{ analogous to rl.xlow, but for shape parameter. }
  \item{xi.xup}{ analogous to rl.xup, but for shape parameter. }
  \item{conf}{ desired confidence. }
  \item{nint}{ number of values (ret. level and/or shape parameter) to compute in trying to find confidence bounds. }
  \item{rl.only}{ logical, if TRUE calculate only the return level confidence intervals. }
  \item{xi.only}{ logical, if TRUE calculate only the shape parameter confidence intervals. }
  \item{make.plot}{ logical, if TRUE plots profile likelihoods. }
}
\details{
This is a fairly rough routine, and is designed mainly to work internally with the extRemes GUI dialogs.
However, it can be used externally with care.  It makes use of a bisection search and spline fitting in order
to find where the profile likelihood crosses the horizontal line through c; the maximum log-likelihood less the
associated chi-square quantile.
}
\value{ A list with components:
  \item{upcross.level}{ the maximum log-likelihood value less the associated chi-square quantile.}
  \item{rl}{a list object containing the return level characteristics.  Including: the maximum likelihood
		estimate for the m-year return level (mle), the spline function used to estimate the profile
		likelihood (sfun), and the upper (up) and lower (dn) confidence limits.}
  \item{xi}{Shape parameter characteristics--analogous to rl, but no mle component.}
}
\references{ Coles, Stuart (2001).  An Introduction to Statistical Modeling of
        Extreme Values.  Springer-Verlag, London.}
\author{ Eric Gilleland }

\seealso{ \code{gev.fit}, \code{gpd.fit}, \code{gev.diag}, \code{gpd.diag}, \code{gev.prof}, \code{gev.profxi},
	\code{gpd.prof}, \code{gpd.profxi}}
\examples{
# See extRemes tutorial for examples using the GUI interface.
}
\keyword{ manip }
\keyword{ hplot }

\eof
\name{return.level}
\alias{return.level}
\title{ Computes m-year return levels for GEV and GPD with confidence bounds. }
\description{
Computes confidence limits for m-year return levels for GEV and GPD using
profile likelihoods and a cubic spline ('splinefun').  It also computes
the confidence levels using the ``delta" method.
}
\usage{
return.level(z, conf = 0.05, rlevels= c(10,100,210,510,810,980),
		make.plot = TRUE)
}
\arguments{
  \item{z}{ An object of class "gev.fit" or "gpd.fit" from the \code{gev.fit} or \code{gpd.fit} functions
	from the \code{ismev} library of Stuart Coles (ported to R by Alec Stephenson).}
  \item{conf}{ The confidence level for confidence bounds. }
  \item{rlevels}{ Return levels at which to compute confidence limits with
	profile likelihood plots--the rest will be interpolated with a spline function
	using the R function \code{splinefun}}
  \item{make.plot}{ logical, if 'TRUE' plots the return levels with confidence bounds. }
}
\details{
This function is in part a modification of the functions 'gev.rl' and 'gpd.rl'
from the ismev library.  It allows for the plotted values to be returned
(invisibly) as well as other confidence levels besides 97.5\%.

Confidence levels are computed using both the profile likelihood method (for
return levels given by 'rlevels') with a cubic spline (to interpolate for
many values not given by 'rlevels') and by the delta method described in Coles
(2001). 
}
\value{
	Creates a plot if 'make.plot' is TRUE and returns a list invisibly with components.
  \item{return.level}{ The m-year return levels.}
  \item{return.period}{ The return periods, m.}
  \item{confidence}{ The confidence bounds estimated from the profile likelihood.}
  \item{confidence.delta}{The confidence bounds computed by the delta method.}
  \item{conf.level}{The confidence level.}
}
\references{ Coles, Stuart.  "An Introduction to Statistical Modeling of Extreme Values",
	Springer 2001.  ISBN: 1852334592}
\author{ Eric Gilleland }

\seealso{ From the \code{ismev} package: \code{gev.fit}, \code{gpd.fit}, \code{gev.diag}, \code{gpd.diag},
	\code{gev.rl}, \code{gpd.rl}}

\examples{
# Must have the 'ismev' package loaded.
require( ismev)
data( ftcanmax)
fit <- gev.fit( ftcanmax[,"Prec"])
class( fit) <- "gev.fit" # 'gev.fit' does not actually assign this class,
			 # but it must be done.
return.level( fit)
}
\keyword{ hplot }

\eof
